==> seven-elements-1.0.2%2B1.21.2-sources.jar: io/github/xrickastley/sevenelements/renderer/entity/model/DendroCoreEntityModel.java <==
package io.github.xrickastley.sevenelements.renderer.entity.model;

import io.github.xrickastley.sevenelements.SevenElements;
import io.github.xrickastley.sevenelements.renderer.entity.state.DendroCoreEntityState;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;

public class DendroCoreEntityModel extends class_583<DendroCoreEntityState> {
	public static final class_5601 MODEL_LAYER = new class_5601(SevenElements.identifier("dendro_core"), "all");

	private final class_630 bone;

	public DendroCoreEntityModel(class_630 root) {
		super(root);

		this.bone = root.method_32086("bone");
	}

	public static class_5607 getTexturedModelData() {
		final class_5609 modelData = new class_5609();

		final class_5610 modelPartData = modelData.method_32111();
		final class_5610 bone = modelPartData.method_32117("bone", class_5606.method_32108().method_32101(21, 2).method_32098(-0.5F, -15.0F, -6.5F, 0.0F, 17.0F, 13.0F, new class_5605(0.0F))
		.method_32101(21, 15).method_32098(-7.0F, -15.0F, 0.0F, 13.0F, 17.0F, 0.0F, new class_5605(0.0F))
		.method_32101(25, 2).method_32098(-1.5F, -14.0F, -1.0F, 2.0F, 3.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32090(0.5F, 22.0F, 0.0F));

		bone.method_32117("cube_r1", class_5606.method_32108().method_32101(0, 5).method_32098(0.0F, -10.0F, -5.0F, 0.0F, 12.0F, 10.0F, new class_5605(0.0F))
		.method_32101(0, 15).method_32098(-5.0F, -10.0F, 0.0F, 10.0F, 12.0F, 0.0F, new class_5605(0.0F))
		.method_32101(0, 0).method_32098(-4.0F, -9.0F, -4.0F, 8.0F, 6.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-0.5F, 0.0F, 0.0F, 0.0F, -0.7854F, 0.0F));

		return class_5607.method_32110(modelData, 48, 48);
	}

	@Override
	public void setAngles(DendroCoreEntityState state) {
		float progress = state.field_53328 % 60 == 0
			? 1
			: state.field_53328 % 60;

		bone.method_33425(0, -progress * 0.05f, 0);
	}
}

==> seven-elements-1.0.3%2B1.21-sources.jar: io/github/xrickastley/sevenelements/renderer/entity/model/DendroCoreEntityModel.java <==
package io.github.xrickastley.sevenelements.renderer.entity.model;

import io.github.xrickastley.sevenelements.SevenElements;
import io.github.xrickastley.sevenelements.entity.DendroCoreEntity;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;

public class DendroCoreEntityModel extends class_583<DendroCoreEntity> {
	public static final class_5601 MODEL_LAYER = new class_5601(SevenElements.identifier("dendro_core"), "all");

	private final class_630 bone;

	public DendroCoreEntityModel(class_630 root) {
		this.bone = root.method_32086("bone");
	}

	public static class_5607 getTexturedModelData() {
		final class_5609 modelData = new class_5609();

		final class_5610 modelPartData = modelData.method_32111();
		final class_5610 bone = modelPartData.method_32117("bone", class_5606.method_32108().method_32101(21, 2).method_32098(-0.5F, -15.0F, -6.5F, 0.0F, 17.0F, 13.0F, new class_5605(0.0F))
		.method_32101(21, 15).method_32098(-7.0F, -15.0F, 0.0F, 13.0F, 17.0F, 0.0F, new class_5605(0.0F))
		.method_32101(25, 2).method_32098(-1.5F, -14.0F, -1.0F, 2.0F, 3.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32090(0.5F, 22.0F, 0.0F));

		bone.method_32117("cube_r1", class_5606.method_32108().method_32101(0, 5).method_32098(0.0F, -10.0F, -5.0F, 0.0F, 12.0F, 10.0F, new class_5605(0.0F))
		.method_32101(0, 15).method_32098(-5.0F, -10.0F, 0.0F, 10.0F, 12.0F, 0.0F, new class_5605(0.0F))
		.method_32101(0, 0).method_32098(-4.0F, -9.0F, -4.0F, 8.0F, 6.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-0.5F, 0.0F, 0.0F, 0.0F, -0.7854F, 0.0F));

		return class_5607.method_32110(modelData, 48, 48);
	}

	@Override
	public void setAngles(DendroCoreEntity entity, float limbAngle, float limbDistance, float animationProgress, float headYaw, float headPitch) {

	}

	@Override
	public void animateModel(DendroCoreEntity entity, float limbAngle, float limbDistance, float tickDelta) {
		float progress = (entity.field_6012 + tickDelta) % 60 == 0
			? 1
			: (entity.field_6012 + tickDelta) % 60;

		bone.method_33425(0, -progress * 0.05f, 0);
	}

	@Override
	public void method_2828(class_4587 matrices, class_4588 vertexConsumer, int light, int overlay, int color) {
		bone.method_22699(matrices, vertexConsumer, light, overlay, color);
	}
}
